#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['snowmobile',
 'snowmobile.core',
 'snowmobile.core.cfg',
 'snowmobile.core.pkg_data',
 'snowmobile.core.utils']

package_data = \
{'': ['*'],
 'snowmobile': ['snowmobile.egg-info/*'],
 'snowmobile.core': ['pkg_data/.snowmobile/*', 'pkg_data/.snowmobile/DDL/*']}

extras_require = \
{'test': ['pytest >= 5.0.0']}

setup(name='snowmobile',
      version='0.2.0b15',
      description='An analytics-focused wrapper around the snowflake.connector for Python.',
      author='Grant Murray',
      author_email='gmurray203@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='>=3.7',
     )
